---
title: Forgejo v9.0 is available
publishDate: 2024-10-16
tags: ['releases']
release: 9.0.0
excerpt: Forgejo v9.0 is available. It is the first version to be released under a copyleft license. Forgejo has early support for a soft-quota that can protect your server from high disk usage due to abuse. It also removes support for go-git, considered too hazardous for daily usage compared to Git. The translations saw an unprecedented number of improvements thanks to the hackathon organized by Codeberg.
---

[Forgejo v9.0](/download/) was released 16 October 2024. You will find a short selection of the changes it introduces below and a [complete list in the release notes](https://codeberg.org/forgejo/forgejo/milestone/7235).

If stability is more important than new features, consider using Forgejo v7.0 instead: it is a Long Term Support release that will receive bug fixes until 16 July 2025. Forgejo v9.0 will be supported until [15 January 2025](https://forgejo.org/docs/next/contributor/release/#release-cycle), when Forgejo v10.0 is published.

A [dedicated test instance](https://v9.next.forgejo.org/) is available to try it out. Before upgrading it is _strongly recommended_ to make a full backup as explained in the [upgrade guide](/docs/v9.0/admin/upgrade/) and carefully read _all breaking changes_ from the [release notes](https://codeberg.org/forgejo/forgejo/milestone/7235). If in doubt, do not hesitate to ask for help [on the Fediverse](https://floss.social/@forgejo), or [in the chat room](https://matrix.to/#/#forgejo-chat:matrix.org).

## Summary

Forgejo v9.0 is the first version to be released under a copyleft license, [after a year of discussions](https://forgejo.org/2024-08-monthly-update/#forgejo-is-now-copyleft). Among the motivations for this change is the realization that a pattern emerged over the years, exemplified by Redis, CockroachDB, Terraform and many others. They turned proprietary because people chose their own financial gain over the interest of the general public. Forgejo admins no longer have to worry about this sword of Damocles: relicensing it as a proprietary software is not allowed.

The removal of the [go-git](https://github.com/go-git/go-git) backend is part of a larger effort to make Forgejo easier to maintain, more robust and even smaller than it already is (~100MB). When presented with `go-git` as an alternative to Git, a Forgejo admin may overlook that it has less features and a history of [corrupting repositories](https://github.com/go-git/go-git/issues/878). It would have been possible to work on documentation and new tests to ensure administrators do not run into these pitfalls, but the effort would have been out of proportion compared to the benefits it provides.

The Forgejo localization community was created early 2024 with the ambitious goal of gaining enough momentum to sustain a long term effort. A daunting task considering there are over 5,000 strings to translate, verify and improve. There has been many calls for help in the past and the community keeps growing steadily. Fortunately, the [translation hackathon (translathon)](https://codeberg.org/Codeberg/translathon-2024#translathon-2024) organized by Codeberg in October was exceptional. It attracted an unprecedented number of participants who improved or created thousands of translations.

## New features

Below is short selection of the most notable changes. The [complete list is available in the release notes](https://codeberg.org/forgejo/forgejo/milestone/7235).

- [PR](https://codeberg.org/forgejo/forgejo/pulls/4212): Added the foundations of a flexible, configurable quota system.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/4819): Allow push mirrors to use an SSH key as the authentication method for the mirroring action instead of using user:password authentication. The SSH keypair is created by Forgejo and the destination repository must be configured with the public key to allow for push over SSH.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/1445): A release asset can be a URL instead of a file.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/4490): Accessibility keyboard support for test actions.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/5482) ([backported](https://codeberg.org/forgejo/forgejo/pulls/5524)): "Assign to me" button on Pull Requests and Issues.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/4903): Support grouping by any path for arch package.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/4780): Add signature support for the RPM module.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/4801): [commit](https://codeberg.org/forgejo/forgejo/commit/feb43b2584b7f64ec7f9952af2b50b2210e6e6cf) The actions logs older than `[actions].LOG_RETENTION_DAYS` days are removed (the default is 365).
- [PR](https://codeberg.org/forgejo/forgejo/pulls/4607): [commit](https://codeberg.org/forgejo/forgejo/commit/d0227c236aa195bd03990210f968b8e52eb20b79) issue Templates: add option to have dropdown printed list.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/2869): Logs journald integration.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/4710): Refactor repository migration items.

## Copyleft

[The impact of the license change](https://forgejo.org/2024-08-gpl/) has been carefully considered with regard to the variety of usages of Forgejo. Someone might have chosen to avoid copyleft software, for example because it is discouraged in a company. However, Forgejo depends on Git, one of the most successful pieces of copyleft software. Both Forgejo and Git must be used together, either as individual binaries or bundled into the [official container images](https://codeberg.org/forgejo-experimental/-/packages/container/forgejo/v9.0-test). The license of Git is [GNU GPL v2](https://git-scm.com/about/free-and-open-source), another version of the same [copyleft license](https://www.gnu.org/licenses/copyleft.html).

The majority of Forgejo's codebase is still MIT-licensed, but it is expected that an increasing number of files will switch to GNU GPL v3+ over time. With the notable exception of the [API swagger file that is and will stay MIT](https://codeberg.org/forgejo/forgejo/pulls/5083) to clarify that the intent of the Forgejo authors is that it is used for interoperability with no restriction. It is not an original work and enforcing copyright on that file would probably be difficult anyway.

## Quotas

Forgejo got early support for a soft-quota system that can protect your server from high disk usage due to abuse or user mistakes. This feature is still in development. If you will try to use it, consider sending us feedback via [a discussion](https://codeberg.org/forgejo/discussions/issues/), or the Matrix channels.

Forgejo has chosen to use a "soft" quota implementation. It means that Forgejo checks the quota usage only before an action is executed, but it will allow a started action to complete.

In some cases (like pushing to Git repositories), it is hard to estimate the exact new size, because it depends on how much data is available and how much we can benefit from compression. As a result, it is possible to exceed the quota if the operation was started before the quota was used up. After the quota is exceeded, new operations that would increase the quota won't be possible.

Furthermore, there is currently little support for early prevention of operations in the UI: The handling of, for example, web operations that are denied later is not yet optimal.

Read more in the [Soft-Quota page of the documentation](https://forgejo.org/docs/v9.0/admin/quota/).

## The multi-architecture OCI leak is fixed

When a multi-architecture container image is pushed to the Forgejo registry, the same tag is used but refers to different images. This is what Forgejo itself relies on to provide [either arm64 or amd64](https://codeberg.org/forgejo/-/packages/container/forgejo/7) depending on the platform (e.g. `docker pull codeberg.org/forgejo/forgejo:7`).

This is implemented with [an image index](https://github.com/opencontainers/image-spec/blob/main/image-index.md) which points to [image manifests](https://github.com/opencontainers/image-spec/blob/main/manifest.md). This level of indirection was unfortunately not taken into account when cleaning up dangling blobs. When a multi-architecture image was either deleted from the web interface or overridden by pushing new images with the same tag, the blobs were never deleted. This bug has been present in Forgejo since the beginning and went unnoticed for a long time, presumably because multi-architecture images are uncommon.

Forgejo will remove dangling blobs when it starts as well as in the existing daily container image cleanup. This will show in the logs with when looking for `grep -i CleanupSHA256`:

```
2024/10/15 00:00:00 ...er/cleanup_sha256.go:106:cleanupSHA256() [I] Nothing to cleanup
2024/10/15 00:00:00 ...er/cleanup_sha256.go:29:CleanupSHA256() [I] Finished to cleanup dangling images with a sha256:* version
```

The time required for the cleanup to complete should be under a minute, even if ten of thousands of blobs were leaked. It is however recommended to give it a try using a backup of the Forgejo instance to be sure. For instance when https://code.forgejo.org was upgraded, it cleaned up a few thousand dangling blobs for a total of around 50GB within less than 15 seconds. To accommodate large instances such as Codeberg, blobs are cleaned up 500 at a time.

## Removal of go-git support

Forgejo used to have 2 Git backends: the normal git and [go-git](https://github.com/go-git/go-git) which is a Git implementation in pure Go. This the benefit of being a little bit faster than Git on Windows.

Supporting go-git would mean holding Forgejo back. Every Git Feature that Forgejo wants to use also needs to be implemented in go-git. For example: setting git notes in the Web UI is currently not possible in go-git. In addition go-git may lead to data loss and repository corruption [(one example)](https://github.com/go-git/go-git/issues/878). It is not widely used and does not have extensive testing (see [the latest example of such corruption](https://github.com/go-git/go-git/issues/878)).

For these reasons, [go-git was removed from the codebase](https://codeberg.org/forgejo/forgejo/pulls/4941). It only affects users who built Forgejo manually using `TAGS=gogit`, which no longer has any effect. This removal only happened in the development branch and not in the existing stable Forgejo branches, up to `v8.0/forgejo` included.

## Transparent removal of Couchbase

Using [Couchbase as a session provider was removed](https://codeberg.org/forgejo/forgejo/pulls/5090). This is not a breaking change because it will transparently fallback to the file provider. The rationale for removing Couchbase support is that it is [not free software](https://www.couchbase.com/blog/couchbase-adopts-bsl-license/) and therefore cannot be tested in Forgejo and neither should be supported.

## Gitea compatibility

Forgejo v9.0 has [automated upgrade tests from Gitea v1.22 to Forgejo v9.0](https://code.forgejo.org/forgejo/end-to-end/src/branch/main/upgrade/upgrade.sh#L56-L57).

- An instance running Gitea versions up to v1.21 can be upgraded to Forgejo v7.0 or v8.0
- An instance running Gitea v1.22 can be upgraded to Forgejo v8.0 or Forgejo v9.0

Read more about [Gitea compatibility in the blog post explaining the hard fork that happened in February 2024](/2024-02-forking-forward/).

## Release schedule and Long Term Support

The [time based release schedule](/docs/v9.0/contributor/release/#release-cycle) was established to publish a release every three months. Patch releases will be published more frequently, depending on the severity of the bug or security fixes they contain.

| **Date** | **Version** | **Release date** | **End Of Life**  |
| -------- | ----------- | ---------------- | ---------------- |
| 2024 Q1  | **7.0.0**   | 23 April 2024    | **16 July 2025** |
| 2024 Q2  | 8.0.0       | 30 July 2024     | 16 October 2024  |
| 2024 Q3  | **9.0.0**   | 16 October 2024  | 15 January 2025  |
| 2025 Q1  | 10.0.0      | 15 January 2025  | 16 April 2025    |

### 9.0-test daily releases

Releases are built daily from the latest changes found in the [v9.0/forgejo](https://codeberg.org/forgejo/forgejo/src/branch/v9.0/forgejo) development branch. They are deployed to the https://v9.next.forgejo.org instance for manual verification in case a bug fix is of particular interest ahead of the next patch release. It can also be installed locally with:

- OCI images: [root](https://codeberg.org/forgejo-experimental/-/packages/container/forgejo/9.0-test) and [rootless](https://codeberg.org/forgejo-experimental/-/packages/container/forgejo/9.0-test-rootless)
- [Binaries](https://codeberg.org/forgejo-experimental/forgejo/releases/tag/v9.0-test)

Their names are staying the same but they are replaced by new builds every day.

## Localization

This release contains many translation additions and improvements done by contributors on [Codeberg Translate](https://translate.codeberg.org/projects/forgejo/forgejo/), and numerous improvements to the UX and translatability of English locale.

Translation updates and some improvements of English locale were also ported to v7.0 where there was no risk of regressions.

The [translation hackathon (translathon)](https://codeberg.org/Codeberg/translathon-2024#translathon-2024) organized by Codeberg in October resulted in many new contributors joining and making thousands of additions and improvements.

## Get Forgejo v9.0

See the [download page](/download/)
for instructions on how to install Forgejo, and read the
[release notes](https://codeberg.org/forgejo/forgejo/milestone/7235)
for more information.

### Upgrading

Carefully read the
[breaking changes](https://codeberg.org/forgejo/forgejo/milestone/7235)
section of the release notes.

The actual upgrade process is as simple as replacing the binary or container image
with the corresponding [Forgejo binary](https://codeberg.org/forgejo/forgejo/releases/tag/v9.0.0)
or [container image](https://codeberg.org/forgejo/-/packages/container/forgejo/9.0.0).
If you're using the container images, you can use the
[`9.0` tag](https://codeberg.org/forgejo/-/packages/container/forgejo/9.0)
to stay up to date with the latest `9.0.Y` patch release automatically.

Make sure to check the [Forgejo upgrade
documentation](/docs/v9.0/admin/upgrade) for
recommendations on how to properly backup your instance before the
upgrade.

### Contribute to Forgejo

If you have any feedback or suggestions for Forgejo do not hold back, it is also your project.
Open an issue in [the issue tracker](https://codeberg.org/forgejo/forgejo/issues)
for feature requests or bug reports, reach out [on the Fediverse](https://floss.social/@forgejo),
or drop into [the Matrix space](https://matrix.to/#/#forgejo:matrix.org)
([main chat room](https://matrix.to/#/#forgejo-chat:matrix.org)) and say hi!

### Donate

Forgejo is proud to be [funded transparently](https://codeberg.org/forgejo/sustainability/). Additionally it accept donations [through Liberapay](https://liberapay.com/forgejo). It is also possible to [donate to Codeberg e.V.](https://docs.codeberg.org/improving-codeberg/donate/) in case the Liberapay option does not work out for you, and part of the funding is used to [compensate for work on Forgejo](https://codeberg.org/forgejo/sustainability/#forgejo-resources-per-year).

However, the Liberapay team allows for money to go directly to developers without a round-trip to Codeberg. Additionally, Liberapay allows for a steady and reliable funding stream next to other options, a crucial aspect for the project. The distribution of funds through Liberapay is [transparently controlled using the decision-making process](https://codeberg.org/forgejo/governance/src/branch/main/TEAMS.md#liberapay-team-members), and Forgejo contributors are encouraged to consider applying to benefit from this funding opportunity.

Thank you for using Forgejo and considering a donation, in case your financial situation allows you to.
