---
title: Forgejo v10.0 is available
publishDate: 2025-01-16
tags: ['releases']
release: 10.0.0
excerpt: Forgejo v10.0 is available. TOTP secrets were made more secure. The UI was made more accessible and reworked to improve the UX. Searching users, repositories, releases and issues was improved. Low German (Plattdüütsch) translation was completed. This is the last version to allow a transparent upgrade from Gitea v1.22 or lower.
---

[Forgejo v10.0](/download/) was released 16 January 2025. You will find a short selection of the changes it introduces below and a [complete list in the release notes](https://codeberg.org/forgejo/forgejo/milestone/8377).

This release marks the end of life for the previous stable version v9. The LTS series Forgejo v7 is still supported until 16 July 2025. Forgejo v10.0 will be supported until [16 April 2025](https://forgejo.org/docs/next/admin/release-schedule/), when Forgejo v11.0 is published. Admins of Forgejo instances with version v9 are recommended to prepare for an upgrade in time so that applying potential future security patches does not involve a major upgrade.

A [dedicated test instance](https://v10.next.forgejo.org/) is available to try it out. Before upgrading it is _strongly recommended_ to make a full backup as explained in the [upgrade guide](/docs/v10.0/admin/upgrade/) and carefully read _all breaking changes_ from the [release notes](https://codeberg.org/forgejo/forgejo/milestone/8377). If in doubt, do not hesitate to ask for help [on the Fediverse](https://floss.social/@forgejo), or [in the chat room](https://matrix.to/#/#forgejo-chat:matrix.org).

## Summary

Forgejo v10.0 is [the last version to allow a transparent upgrade from Gitea v1.22 or lower](/2024-12-gitea-compatibility/). In 2023 Forgejo was a soft fork, a set of patches maintained by the Forgejo community on top of Gitea. Early 2024 [it became a hard fork](/2024-02-forking-forward/) and the codebases started to diverge. Forgejo and Gitea are now effectively different codebases although they share the same history back from the early days of Gogs.

If you are running Gitea v1.22 or lower and consider migrating to Forgejo long after v10.0 was published, [it will still be possible](https://forgejo.org/docs/next/admin/upgrade/#preparing-an-upgrade-from-gitea), provided you upgrade to Forgejo v10.0 first and then upgrade to a newer Forgejo version. This will be a two steps upgrade instead of a single step.

## New features

Below is short selection of the most notable changes. The [complete list is available in the release notes](https://codeberg.org/forgejo/forgejo/milestone/8377).

- [PR](https://codeberg.org/forgejo/forgejo/pulls/6386): Rework the new repository dialog.
  ![New repository dialog](./_images/2025-01-create-repo.webp)
- [PR](https://codeberg.org/forgejo/forgejo/pulls/4753): Git notes can be modified via the API or the UI.
  ![Git notes web UI](./_images/2025-01-git-note.webp)
- [PR](https://codeberg.org/forgejo/forgejo/pulls/5589): Add button to create Markdown table.
  ![Add a table to a comment](./_images/2025-01-comment-table.webp)
- [PR](https://codeberg.org/forgejo/forgejo/pulls/5677): If you select a portion of a comment and use the 'Quote reply' feature in the context menu, only that portion will be quoted. The markdown syntax is preserved.
  ![Comment including a highlighted text quote](./_images/2025-01-comment-quote.webp)
- [PR](https://codeberg.org/forgejo/forgejo/pulls/4125): Add link to show all issues and pull requests.
  ![Issues view including all of them](./_images/2025-01-issues-all.webp)
- [PR](https://codeberg.org/forgejo/forgejo/pulls/5899): Highlight user mention in comments and commit messages.
  ![Highlighted user mention in a comment](./_images/2025-01-ref-highlight.webp)
- [PR](https://codeberg.org/forgejo/forgejo/pulls/6053) & [PR](https://codeberg.org/forgejo/forgejo/pulls/6269): Add a "summary card" to issues, PRs, repositories and releases for consumption by OpenGraph clients.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/6143): Filepath filter for code search.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/6274): Add links to commit lists in contributors graph page.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/5777): Add search to releases page.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/6074): Migrate TOTP secrets to `keying`.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/5819): When [bleve is used for issue search](https://forgejo.org/docs/next/admin/config-cheat-sheet/#indexer-indexer), a `fuzzy` search now applies to each word instead of all of them, as if they were a phrase. For instance, searching for `activitypub spam moderation` previously [returned no result in Forgejo discussions](https://v9.next.forgejo.org/snematoda/forgejo-discussions/issues?state=open&type=all&q=activitypub+spam+moderation&fuzzy=true) and now returns the [relevant issues](https://codeberg.org/forgejo/discussions/issues?state=open&type=all&q=activitypub+spam+moderation&fuzzy=true). If the search results are too broad, or for searching exact phrases prefer using an `exact` search. Sorting by newest is still available as a non default option under `Sort`. The query was also reworked to improve performances. It makes a significant difference for large instances such as Codeberg.
- [PR](https://codeberg.org/forgejo/forgejo/pulls/6146): Improve performance of notifications page for MySQL.

## Hardened TOTP secrets

The TOTP secrets were stored using the [secret module](https://codeberg.org/forgejo/forgejo/src/commit/de4053db8370c5d06adb48165fd833363333c5ea/modules/secret/). They now use the [keying module](https://codeberg.org/forgejo/forgejo/src/commit/de4053db8370c5d06adb48165fd833363333c5ea/modules/keying/) which is easier to use and relies on better practices to store secrets in a databases.

The `keying` module tries to solve two problems, the lack of key separation and the lack of AEAD being used for encryption. The `secret` module doesn't provide this and is hard to adjust to provide this functionality.

For encryption, the additional data is now a parameter that can be used, as the underlying primitive is an AEAD construction. This allows for context binding to happen and can be seen as defense-in-depth; it ensures that if a value `X` is encrypted for context `Y` (e.g. `ID=3`, `Column="private_key"`) it will only decrypt if that context `Y` is also given in the `Decrypt` function. This makes a [confused deputy](https://en.wikipedia.org/wiki/Confused_deputy_problem) attack harder to exploit.

## Gitea compatibility

Forgejo v10.0 has [automated upgrade tests from Gitea v1.22 to Forgejo v10.0](https://code.forgejo.org/forgejo/end-to-end/src/branch/main/upgrade/upgrade.sh#L56-L57).

- An instance running Gitea versions up to v1.21 can be upgraded to Forgejo v7.0 or v8.0
- An instance running Gitea v1.22 can be upgraded to Forgejo v8.0, v9.0 or v10.0

Future Forgejo versions will not support upgrades from Gitea instances running version v1.23 or above. Read more about [Gitea compatibility and upgrades in the dedicated blog post](/2024-12-gitea-compatibility/).

## Note on some harmless warnings

You may see migration warnings (and in some cases errors) when Forgejo starts. Most of them can be ignored as long as they do not prevent the instance from starting. However, they are confusing and you may want to get rid of them. More information can be found about that in the [corresponding issue](https://codeberg.org/forgejo/forgejo/issues/6583), as well as instructions to resolve them. If in doubt, do not hesitate to ask for advice.

## Release schedule and Long Term Support

The [time based release schedule](/docs/v10.0/admin/release-schedule/) was established to publish a release every three months. Patch releases will be published more frequently, depending on the severity of the bug or security fixes they contain.

| **Version** | **Release date** | **End Of Life**  |
| ----------- | ---------------- | ---------------- |
| 7.0 (LTS)   | 23 April 2024    | **16 July 2025** |
| 9.0         | 16 October 2024  | 16 January 2025  |
| 10.0        | 16 January 2025  | 16 April 2025    |
| 11.0 (LTS)  | 16 April 2025    | **15 July 2026** |

### 10.0-test daily releases

Releases are built daily from the latest changes found in the [v10.0/forgejo](https://codeberg.org/forgejo/forgejo/src/branch/v10.0/forgejo) development branch. They are deployed to the https://v10.next.forgejo.org instance for manual verification in case a bug fix is of particular interest ahead of the next patch release. It can also be installed locally with:

- OCI images: [root](https://codeberg.org/forgejo-experimental/-/packages/container/forgejo/10.0-test) and [rootless](https://codeberg.org/forgejo-experimental/-/packages/container/forgejo/10.0-test-rootless)
- [Binaries](https://codeberg.org/forgejo-experimental/forgejo/releases/tag/v10.0-test)

Their names are staying the same but they are replaced by new builds every day.

## Localization

This release contains the latest translation updates from the project on Codeberg Translate. They include a significant number of new translations and improvements to many languages, with particularly large refactors in Latvian and Simplified Chinese.

A new language has been made available: Low German (Plattdüütsch). It is already fully completed, only proofreading remains.

A new convenient feature has been added which allows to easily identify translation keys in the interface by simply appending `lang=dummy` to the URL parameters. It is also useful to quickly look up the UI template within the source code.

## Get Forgejo v10.0

See the [download page](/download/)
for instructions on how to install Forgejo, and read the
[release notes](https://codeberg.org/forgejo/forgejo/milestone/8377)
for more information.

### Upgrading

Carefully read the
[Breaking bug fixes](https://codeberg.org/forgejo/forgejo/milestone/8377)
section of the release notes.

The actual upgrade process is as simple as replacing the binary or container image
with the corresponding [Forgejo binary](https://codeberg.org/forgejo/forgejo/releases/tag/v10.0.0)
or [container image](https://codeberg.org/forgejo/-/packages/container/forgejo/10.0.0).
If you're using the container images, you can use the
[`10.0` tag](https://codeberg.org/forgejo/-/packages/container/forgejo/10.0)
to stay up to date with the latest `10.0.Y` patch release automatically.

Make sure to check the [Forgejo upgrade
documentation](/docs/v10.0/admin/upgrade) for
recommendations on how to properly backup your instance before the
upgrade.

### Contribute to Forgejo

If you have any feedback or suggestions for Forgejo do not hold back, it is also your project.
Open an issue in [the issue tracker](https://codeberg.org/forgejo/forgejo/issues)
for feature requests or bug reports, reach out [on the Fediverse](https://floss.social/@forgejo),
or drop into [the Matrix space](https://matrix.to/#/#forgejo:matrix.org)
([main chat room](https://matrix.to/#/#forgejo-chat:matrix.org)) and say hi!

### Donate

Forgejo is proud to be [funded transparently](https://codeberg.org/forgejo/sustainability/). Additionally, it accept donations [through Liberapay](https://liberapay.com/forgejo). It is also possible to [donate to Codeberg e.V.](https://docs.codeberg.org/improving-codeberg/donate/) in case the Liberapay option does not work out for you, and part of the funding is used to [compensate for work on Forgejo](https://codeberg.org/forgejo/sustainability/#forgejo-resources-per-year).

However, the Liberapay team allows for money to go directly to developers without a round-trip to Codeberg. Additionally, Liberapay allows for a steady and reliable funding stream next to other options, a crucial aspect for the project. The distribution of funds through Liberapay is [transparently controlled using the decision-making process](https://codeberg.org/forgejo/governance/src/branch/main/TEAMS.md#liberapay-team-members), and Forgejo contributors are encouraged to consider applying to benefit from this funding opportunity.

Thank you for using Forgejo and considering a donation, in case your financial situation allows you to.
